# Getting Data into Your Workspace
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/get-data-into-workspace#overview)
  * [Best Practices for Building the Inventory](https://help.sap.com/docs/leanix/ea/get-data-into-workspace#best-practices-for-building-the-inventory)
  * [Step 1. Upload Application Data into SAP LeanIX](https://help.sap.com/docs/leanix/ea/get-data-into-workspace#step-1.-upload-application-data-into-sap-leanix)
  * [Step 2. Define and add Business Capabilities](https://help.sap.com/docs/leanix/ea/get-data-into-workspace#step-2.-define-and-add-business-capabilities)
  * [Step 3. Add Organizations](https://help.sap.com/docs/leanix/ea/get-data-into-workspace#step-3.-add-organizations)
  * [Step 4. Link Applications to Business Capabilities and Organizations](https://help.sap.com/docs/leanix/ea/get-data-into-workspace#step-4.-link-applications-to-business-capabilities-and-organizations)
  * [Next Steps](https://help.sap.com/docs/leanix/ea/get-data-into-workspace#next-steps)


Getting initial data into SAP LeanIX workspace.
